# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['baudelaire']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.8,<9.0.0',
 'confuk>=0.6.3,<0.7.0',
 'pillow>=11.1.0,<12.0.0',
 'rich>=13.9.4,<14.0.0']

entry_points = \
{'console_scripts': ['baudelaire = baudelaire:main']}

setup_kwargs = {
    'name': 'baudelaire',
    'version': '0.1.0',
    'description': 'Take a poem and make it an Instagram post',
    'long_description': '<p align="center">\n  <img src="static/logo.png" alt="logo" width="200" style="display: block;margin-left: auto;margin-right: auto;"/>\n</p>\n</br>\nCreate Instagram posts from your plaintext poetry in seconds.\n\n## Installation\n\n```bash\npip install baudelaire\n```\n\n## Usage\n\n```bash\nbaudelaire "<plaintext-input>" -o "<output-directory>" -c "<config>"\n```\n\nFor example:\n\n```bash\nbaudelaire -o "outputs" "$(cat "poem.txt")"\n```\n\n> [!note]\n> The input is expected to be a plaintext poem, so you can write the contents directly in the command line or `cat` them from a plaintext file.\n\nThe text will be written to the specified output directory as `poem_part-*.png` files. There is a default configuration file which is distributed as a part of the package.\n\nYou can give it a try by using Dylan Thomas\' _Do not go gentle into that good night_:\n\n```bash\nbaudelaire -o "outputs" "$(cat "tests/rage.txt")"\n```\n\n## Configuration\n\nThe default config is available in the repository under `config/default.yaml`. Check out the comments to understand what each configuration option does.\n\n> [!note]\n> If you change the font you might need to tweak other parameters like the number of lines per board. It\'s recommended to create a separate config per template.\n',
    'author': 'Chris Czarnecki',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
